Demo using the user button and serial port on the Nucleo board, for Stage 1 Engineering at the University of York

Dependencies:   UoY-serial

Files at this revision

API Documentation at this revision

Comitter:
ajp109
Date:
Thu Sep 16 14:01:20 2021 +0000
Parent:
4:20d75a9afbbd
Commit message:
Update pin name

Changed in this revision

main.cpp Show annotated file Show diff for this revision Revisions of this file
--- a/main.cpp	Sat Nov 21 14:49:27 2020 +0000
+++ b/main.cpp	Thu Sep 16 14:01:20 2021 +0000
@@ -2,8 +2,8 @@
 
 int main()
 {
-    // Initialise the digital pin USER_BUTTON (the blue button) as an input
-    DigitalIn button(USER_BUTTON);
+    // Initialise the digital pin BUTTON1 (the blue button) as an input
+    DigitalIn button(BUTTON1);
 
     // Loop forever...
     while (true) {